pub struct ReadGuard<'a, T: Sized + Sync + 'a> { /* private fields */ }Expand description
A read-guard that can be used to read the underlying data structure. Writes on the data structure will be blocked as long as one of these is lying around.